## Typing stubs for caldav

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`caldav`](https://github.com/python-caldav/caldav) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `caldav`. This version of
`types-caldav` aims to provide accurate annotations for
`caldav==1.3.*`.

*Note:* The `caldav` package includes type annotations or type stubs
since version 1.4.0. Please uninstall the `types-caldav`
package if you use this or a newer version.


This stub package is marked as [partial](https://peps.python.org/pep-0561/#partial-stub-packages).
If you find that annotations are missing, feel free to contribute and help complete them.


This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/caldav`](https://github.com/python/typeshed/tree/main/stubs/caldav)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.400,
and pytype 2024.10.11.
It was generated from typeshed commit
[`126768408a69b7a3a09b7d3992970b289f92937e`](https://github.com/python/typeshed/commit/126768408a69b7a3a09b7d3992970b289f92937e).